@@ -1,6 +1,6 @@
 package CGI::Untaint::asin;
 
-$VERSION = '0.01';
+$VERSION = '1.00';
 
 use strict;
 use base 'CGI::Untaint::object';
@@ -9,6 +9,8 @@ sub _untaint_re {
   qr/^([\d\w]\d{4}[\d\w]{5})$/i;
 }
 
+1;
+
 =head1 NAME
 
 CGI::Untaint::asin - validate an Amazon ID
@@ -32,15 +34,23 @@ L<CGI::Untaint>
 
 =head1 AUTHOR
 
-Tony Bowden, E<lt>kasei@tmtm.comE<gt>. 
+Tony Bowden
+
+=head1 BUGS and QUERIES
+
+Please direct all correspondence regarding this module to:
+  bug-Business-Barcode-EAN13@rt.cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004 Tony Bowden. All rights reserved.
+  Copyright (C) 2004-2005 Tony Bowden.
 
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+  This program is free software; you can redistribute it and/or modify it under
+  the terms of the GNU General Public License; either version 2 of the License,
+  or (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+  FOR A PARTICULAR PURPOSE.
 
 =cut
-
-1;
